import './style.scss'

const registerChromecastPlugin = require('@silvermine/videojs-chromecast')
const registerAirplayPlugin = require('@silvermine/videojs-airplay')

let gcastScriptLoaded = false

function register ({
  registerHook,
  settingsManager,
  peertubeHelpers,
}) {
  registerHook({
    target: 'action:video-watch.video.loaded',
    handler: ({ videojs }) => {
      if (gcastScriptLoaded) return;

      const script = document.createElement('script')
      script.src = 'https://www.gstatic.com/cv/js/sender/v1/cast_sender.js?loadCastFramework=1'
      document.body.appendChild(script)

      registerChromecastPlugin(videojs, { preloadWebComponents: true })
      registerAirplayPlugin(videojs)
      gcastScriptLoaded = true
    },
  })

  registerHook({
    target: 'filter:internal.player.videojs.options.result',
    handler: options => {
      return settingsManager.getSetting('chromecast-receiver-app-id')
        .then((receiverAppID) => {
          return Object.assign(
            {},
            options,
            {
              chromecast: {
                modifyLoadRequestFn: function (loadRequest) {
                  loadRequest.media.hlsSegmentFormat = 'fmp4';
                  loadRequest.media.hlsVideoSegmentFormat = 'fmp4';
                  return loadRequest;
                }
              },
              plugins: Object.assign(
                {},
                options.plugins,
                {
                  chromecast: {
                    receiverAppID: receiverAppID || undefined,
                  },
                  airPlay: {},
                }
              ),
              techOrder: ['chromecast', 'html5'],
            }
        );
      });
    }
  })
}

export {
  register
}
